@@ -1,4 +1,4 @@
-from encryptor import Encryptor
+from simple_encryptor import Encryptor
 
 encryptor = Encryptor("my_secret_key")
 encrypted = encryptor.encrypt("Hello, World!")
